boto v2.9.9 — boto v2.16.0

### Navigation

- index
- modules |
- previous |
- boto v2.16.0 »

# boto v2.9.9

date: | 2013/07/24

This release updates Opsworks to add AMI & Chef 11 support, DBSubnetGroup support in RDS & many other bugfixes.

## Features

- Added AMI, configuration manager & Chef 11 support to Opsworks. (commit 55725fc).
- Added `in` support for SQS messages. (issue 1593, commit e5fe1ed)
- Added support for the `ap-southeast-2` region in Elasticache. (issue 1607, commit 9986b61)
- Added support for block device mappings in ELB. (issue 1343, issue 753, issue 1357, commit 974a23a)
- Added support for DBSubnetGroup in RDS. (issue 1500, commit 01eef87, commit 45c60a0, commit c4c859e)

## Bugfixes

- Fixed the canonicalization of paths on Windows. (issue 1609, commit a1fa98c)
- Fixed how `BotoServerException` uses `message`. (issue 1353, commit b944f4b)
- Fixed `DisableRollback` always being `True` in a CloudFormation `Stack`. (issue 1379, commit 32b3150)
- Changed EMR instance groups to no longer require a string price (can now be a `Decimal`). (issue 1396, commit dfc39ff)
- Altered `Distribution._sign_string` to accept any file-like object as well within CloudFront. (issue 1349, commit 8df6c14)
- Fixed the `detach_lb_from_subnets` call within ELB. (issue 1417, issue 1418 commit 4a397bd, commit c11d72b, commit 9e595b5, commit 634469d, commit 586dd54)
- Altered boto to obey `no_proxy` environment variables. (issue 1600, issue 1603, commit aaef5a9)
- Fixed ELB connections to use HTTPS by default. (issue 1587, commit fe158c4)
- Updated S3 to be Python 2.5 compatible again. (issue 1598, commit 066009f)
- All calls within SES will now return all DKIMTokens, instead of just one. (issue 1550, issue 1610, commit 1a079da, commit 1e82f85, commit 5c8b6b8)
- Fixed the `logging` parameter within `DistributionConfig` in CloudFront to respect whatever is provided to the constructor. (issue 1457, commit e76180d)
- Fixed CloudSearch to no longer raise an error if a non-JSON response is received. (issue 1555, issue 1614, commit 5e2c292, commit 6510e1f)

### Navigation

- index
- modules |
- previous |
- boto v2.16.0 »